==> github-scraper-6.7.0.tgz: package/test/org.test.js <==
var test = require('tape');
var org  = require('../lib/switcher');
var dir  = __dirname.split('/')[__dirname.split('/').length-1];
var file = dir + __filename.replace(__dirname, '') + " > ";

test(file + 'Scrape an org WITHOUT a next page (known data)', function(t){
	var url = '/peersun';
	org(url, function(err, data) {
		t.equal(data.type, 'org', url + ' data.type: ' + data.type);
		t.ok(data.entries.length > 5, 'org '
			+ url + ' has ' + data.entries.length + ' repos.')
		t.ok(data.pcount === 0, '"pcount":' + data.pcount);

		const last = data.entries[data.entries.length-1];
		t.equal(last.updated, '2014-02-18T23:09:24Z',
			'last.updated: ' + last.updated);
		// console.log(' - - - - - - - - - - - - - data.entries:');
		// console.log(data.entries);
		// console.log(' - - - - - - - - - - - - -');
		t.end();
	});
})

test(file + 'Scrape an org WITH a next page', function(t){
	var url = '/github';
	org(url, function(err, data) {
		t.ok(data.pcount > 100, '"pcount":'+data.pcount);
		t.ok(data.location === 'San Francisco, CA', 'data.location: '+data.location);
		t.ok(data.website === 'https://github.com/about', 'data.url: '+data.url);
		t.ok(data.email === 'support@github.com', 'data.email: '+data.email);
		t.equal(data.uid, 9919, url + ' uid is ' + data.uid);
		t.end();
	});
})

test(file + 'Fetch Second page of dwyl org', function (t) {
	let url = 'dwyl';
	org(url, function(err, data) {
		// console.log(data.entries);
		t.ok(data.entries.length === 30, 'SECOND page of org has '+data.entries.length + ' repos')
		t.ok(data.pcount > 10, '"pcount":'+data.pcount);
		t.ok(data.next_page === '/dwyl?page=2', 
			'data.next_page is: ' + data.next_page);

		url = '/dwyl?page=2';
		org(url, function(err, data) {
			// console.log(data);
			t.ok(data.entries.length === 30, 'SECOND page of org has '+data.entries.length + ' repos')
			t.ok(data.pcount > 10, '"pcount":'+data.pcount);
			t.ok(data.next_page === '/dwyl?page=3', 'dwyl has more than one page');
			t.end();
		});
	});
})

test(file + 'ORG with no people', function(t){
	var url = '/pandajs';
	org(url, function(err, data) {
		// console.log('data', data);
		t.equal(data.description, 
			"people who are super into pandas and javascript!", 
			'data.description: ' + data.description)
		t.ok(typeof data.website === 'undefined', "No website")
		t.ok(typeof data.location === 'undefined', "No location")
		t.ok(typeof data.email === 'undefined', "No email")
		t.ok(data.pcount === 0, url + ' "pcount":'+data.pcount);
		t.end();
	});
})

==> github-scraper-7.0.1.tgz: package/test/org.test.js <==
var test = require('tape');
var org  = require('../lib/switcher');
var dir  = __dirname.split('/')[__dirname.split('/').length-1];
var file = dir + __filename.replace(__dirname, '') + " > ";

test(file + 'Scrape an org WITHOUT a next page (known data)', function(t){
	var url = '/peersun';
	org(url, function(err, data) {
		t.equal(data.type, 'org', url + ' data.type: ' + data.type);
		t.ok(data.entries.length > 5, 'org '
			+ url + ' has ' + data.entries.length + ' repos.')
		// t.ok(data.pcount === 0, '"pcount":' + data.pcount);

		const last = data.entries[data.entries.length-1];
		t.equal(last.updated, '2014-02-18T23:09:24Z',
			'last.updated: ' + last.updated);
		// console.log(' - - - - - - - - - - - - - data.entries:');
		// console.log(data.entries);
		// console.log(' - - - - - - - - - - - - -');
		t.end();
	});
})

test(file + 'Scrape an org WITH a next page', function(t){
	var url = '/github';
	org(url, function(err, data) {
		// delete(data.entries)
		// console.log(err, data);
		// t.ok(data.pcount > 100, '"pcount":'+data.pcount);
		t.ok(data.location === 'San Francisco, CA', 'data.location: '+data.location);
		t.ok(data.website === 'https://github.com/about', 'data.url: '+data.url);
		t.ok(data.email === 'support@github.com', 'data.email: '+data.email);
		t.equal(data.uid, 9919, url + ' uid is ' + data.uid);
		t.end();
	});
})

test(file + 'Fetch Second page of dwyl org', function (t) {
	let url = 'dwyl';
	org(url, function(err, data) {
		// console.log(data.entries);
		t.ok(data.entries.length === 30, 'SECOND page of org has '+data.entries.length + ' repos')
		// t.ok(data.pcount > 10, '"pcount":'+data.pcount);
		t.ok(data.next_page === '/dwyl?page=2',
			'data.next_page is: ' + data.next_page);

		url = '/dwyl?page=2';
		org(url, function(err, data) {
			// console.log(data);
			t.ok(data.entries.length === 30, 'SECOND page of org has '+data.entries.length + ' repos')
			// t.ok(data.pcount > 10, '"pcount":'+data.pcount);
			t.ok(data.next_page === '/dwyl?page=3', 'dwyl has more than one page');
			t.end();
		});
	});
})

test(file + 'ORG with no people', function(t){
	var url = '/pandajs';
	org(url, function(err, data) {
		// console.log('data', data);
		t.equal(data.description,
			"people who are super into pandas and javascript!",
			'data.description: ' + data.description)
		t.ok(typeof data.website === 'undefined', "No website")
		t.ok(typeof data.location === 'undefined', "No location")
		t.ok(typeof data.email === 'undefined', "No email")
		// t.ok(data.pcount === 0, url + ' "pcount":'+data.pcount);
		t.end();
	});
})
